==> haskell-aeson-qq-0.8.2-26-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-aeson-qq.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: aeson-qq
version: 0.8.2
id: aeson-qq-0.8.2-CHfWFY9nlFrFyoLpyhVoqS
key: aeson-qq-0.8.2-CHfWFY9nlFrFyoLpyhVoqS
license: MIT
maintainer: Simon Hengel <sol@typeful.net>
homepage: https://github.com/sol/aeson-qq#readme
synopsis: JSON quasiquoter for Haskell
description:
    @aeson-qq@ provides a JSON quasiquoter for Haskell.
    .
    This package exposes the function `aesonQQ` that compile-time
    converts a string representation of a JSON value into a
    `Data.Aeson.Value`.  `aesonQQ` has the signature
    .
    >aesonQQ :: QuasiQuoter
    .
    Consult the @README@ for documentation:
    <https://github.com/sol/aeson-qq#readme>
category: JSON
author: Oscar Finnsson
exposed: True
indefinite: False
exposed-modules:
    Data.Aeson.QQ
hidden-modules: Data.JSON.QQ Paths_aeson_qq
abi: 2ebeef38aff6c58b249cd6b635cb26d4
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/aeson-qq-0.8.2
library-dirs: /usr/lib/ghc-8.2.2/site-local/aeson-qq-0.8.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.2/aeson-qq-0.8.2
hs-libraries: HSaeson-qq-0.8.2-CHfWFY9nlFrFyoLpyhVoqS
depends:
    base-4.10.1.0 base-compat-0.9.3-915GC5pH10BBmcMnCvMsPA
    text-1.2.3.0-FxgEmn4RjqC37dwdnPGDhj
    attoparsec-0.13.2.2-1iFrnKzrZDOGKCpRsHPeZj
    scientific-0.3.5.3-HgtwFQ4gEJZ599U6d6bYAG
    vector-0.12.0.1-JlawpRjIcMJIYPJVsWriIA
    aeson-1.2.4.0-6eoM9racNXa30gbnEGQwXU
    parsec-3.1.13.0-lnA0oAxTgL1KjACiBdQ3F template-haskell-2.12.0.0
    haskell-src-meta-0.8.0.2-JH58Enx2N14E5SeQCSdUGO
abi-depends: base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
             base-compat-0.9.3-915GC5pH10BBmcMnCvMsPA=5a5696f2eea50c76cb741a2b4cb0b84c
             text-1.2.3.0-FxgEmn4RjqC37dwdnPGDhj=d51c5ac73448d7d6c9cbe4dedb95457e
             attoparsec-0.13.2.2-1iFrnKzrZDOGKCpRsHPeZj=9d8982f8b70cf41a2e1b007eb9382565
             scientific-0.3.5.3-HgtwFQ4gEJZ599U6d6bYAG=490d099f5e386f4f486a599d7d1e6789
             vector-0.12.0.1-JlawpRjIcMJIYPJVsWriIA=a99b30cfe85615e5f75a9a70e1864f51
             aeson-1.2.4.0-6eoM9racNXa30gbnEGQwXU=34f15a624c6fc087743b1cf3621b819b
             parsec-3.1.13.0-lnA0oAxTgL1KjACiBdQ3F=688f5e7444a80128e4a1c39bd128d195
             template-haskell-2.12.0.0=2257617827b0258ca46e933b344007b7
             haskell-src-meta-0.8.0.2-JH58Enx2N14E5SeQCSdUGO=9abc1639fb2960ed591009d00159e7f3
haddock-interfaces: /usr/share/doc/haskell-aeson-qq/html/aeson-qq.haddock
haddock-html: /usr/share/doc/haskell-aeson-qq/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-aeson-qq-0.8.2-27-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-aeson-qq.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: aeson-qq
version: 0.8.2
id: aeson-qq-0.8.2-FYMOyu7vnaDBtpx6dHjAPX
key: aeson-qq-0.8.2-FYMOyu7vnaDBtpx6dHjAPX
license: MIT
maintainer: Simon Hengel <sol@typeful.net>
homepage: https://github.com/sol/aeson-qq#readme
synopsis: JSON quasiquoter for Haskell
description:
    @aeson-qq@ provides a JSON quasiquoter for Haskell.
    .
    This package exposes the function `aesonQQ` that compile-time
    converts a string representation of a JSON value into a
    `Data.Aeson.Value`.  `aesonQQ` has the signature
    .
    >aesonQQ :: QuasiQuoter
    .
    Consult the @README@ for documentation:
    <https://github.com/sol/aeson-qq#readme>
category: JSON
author: Oscar Finnsson
exposed: True
indefinite: False
exposed-modules:
    Data.Aeson.QQ
hidden-modules: Data.JSON.QQ Paths_aeson_qq
abi: 8df04e3dd38918fac3b1bae693a8c31a
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/aeson-qq-0.8.2
library-dirs: /usr/lib/ghc-8.2.2/site-local/aeson-qq-0.8.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.2/aeson-qq-0.8.2
hs-libraries: HSaeson-qq-0.8.2-FYMOyu7vnaDBtpx6dHjAPX
depends:
    base-4.10.1.0 base-compat-0.9.3-915GC5pH10BBmcMnCvMsPA
    text-1.2.3.0-FxgEmn4RjqC37dwdnPGDhj
    attoparsec-0.13.2.2-1iFrnKzrZDOGKCpRsHPeZj
    scientific-0.3.5.3-HgtwFQ4gEJZ599U6d6bYAG
    vector-0.12.0.1-JlawpRjIcMJIYPJVsWriIA
    aeson-1.2.4.0-6eoM9racNXa30gbnEGQwXU
    parsec-3.1.13.0-lnA0oAxTgL1KjACiBdQ3F template-haskell-2.12.0.0
    haskell-src-meta-0.8.0.2-JH58Enx2N14E5SeQCSdUGO
abi-depends: base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
             base-compat-0.9.3-915GC5pH10BBmcMnCvMsPA=5a5696f2eea50c76cb741a2b4cb0b84c
             text-1.2.3.0-FxgEmn4RjqC37dwdnPGDhj=d51c5ac73448d7d6c9cbe4dedb95457e
             attoparsec-0.13.2.2-1iFrnKzrZDOGKCpRsHPeZj=9d8982f8b70cf41a2e1b007eb9382565
             scientific-0.3.5.3-HgtwFQ4gEJZ599U6d6bYAG=490d099f5e386f4f486a599d7d1e6789
             vector-0.12.0.1-JlawpRjIcMJIYPJVsWriIA=a99b30cfe85615e5f75a9a70e1864f51
             aeson-1.2.4.0-6eoM9racNXa30gbnEGQwXU=34f15a624c6fc087743b1cf3621b819b
             parsec-3.1.13.0-lnA0oAxTgL1KjACiBdQ3F=688f5e7444a80128e4a1c39bd128d195
             template-haskell-2.12.0.0=2257617827b0258ca46e933b344007b7
             haskell-src-meta-0.8.0.2-JH58Enx2N14E5SeQCSdUGO=9abc1639fb2960ed591009d00159e7f3
haddock-interfaces: /usr/share/doc/haskell-aeson-qq/html/aeson-qq.haddock
haddock-html: /usr/share/doc/haskell-aeson-qq/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
